@@ -12,14 +12,14 @@ class ExternalConfigFile: # pylint: disable=R0903
     @property
     def file_content(self) -> str:
         """ Reads file content from the disk & returns """
-        with open(self.path, "r", encoding="utf-8") as text_file:
+        with open(self.path, "r") as text_file:
             output = text_file.read()
         return output
 
     @file_content.setter
     def file_content(self, p_content: str):
         """ Writes file content to disk """
-        with open(self.path, "w", encoding="utf-8") as text_file:
+        with open(self.path, "w") as text_file:
             text_file.write(p_content)
 
 
