@@ -78,7 +78,7 @@ class Unzipper:
             file_in_zip = os.path.split(extracted_path)[1]
 
             if file_format == AttachmentFormat.text:
-                with open(extracted_path, "r", encoding="utf-8") as extracted_file:
+                with open(extracted_path, "r") as extracted_file:
                     file_content = extracted_file.read()
                     file_content = file_content.replace("\n", " ")
                     file_content = file_content.replace("\t", " ")
