@@ -1,10 +1,9 @@
 """ Abstract processor factory module """
-from abc import ABC, abstractmethod
 from enum import Enum
+from typing import Protocol
 from databus.client.log import Log
 from databus.processor.abstract_processor import AbstractProcessor
 
-
 class ProcessorCreationError(Exception):
     """ Abstract processor creation exception """
     class ErrorCode(Enum):
@@ -25,14 +24,13 @@ class ProcessorCreationError(Exception):
     def message(self) -> str:
         """ Error message as text """
         if self.error_code == ProcessorCreationError.ErrorCode.cant_create_instance:
-            return "Can't create " + self.module + " processor instance"
+            return f"Can't create {self.module} processor instance"
         if self.error_code == ProcessorCreationError.ErrorCode.parameter_missing:
             return "Parameters missing, can't create processor instance"
         return "Processor creation error"
 
 
-class AbstractProcessorFactory(ABC): # pylint: disable=R0903
+class AbstractProcessorFactory(Protocol): # pylint: disable=R0903
     """ Abstract processor factory """
-    @abstractmethod
     def create_processor(self, p_module: str, p_log: Log) -> AbstractProcessor:
         """ Processor factory """
